@@ -4,6 +4,8 @@ import pandas.util.testing as tm
 import pandas_datareader.data as web
 
 from pandas import DataFrame
+from pandas_datareader._utils import RemoteDataError
+from pandas_datareader._testing import skip_on_exception
 from pandas_datareader.data import DataReader
 
 
@@ -15,10 +17,13 @@ class TestOptionsWarnings(object):
 
 
 class TestDataReader(object):
+
+    @skip_on_exception(RemoteDataError)
     def test_read_yahoo(self):
         gs = DataReader("GS", "yahoo")
         assert isinstance(gs, DataFrame)
 
+    @pytest.mark.xfail(RemoteDataError, reason="failing after #355")
     def test_read_yahoo_dividends(self):
         gs = DataReader("GS", "yahoo-dividends")
         assert isinstance(gs, DataFrame)
